import os
import click


@click.group()
def main():
    """
    Simple CLI for managing Makefile
    """
    pass


@main.command()
def init():
    makefile_exists = os.path.isfile("./Makefile")
    if not makefile_exists:
        with open("./Makefile", "a+") as f:
            f.write("# Makefile generated with pymakefile \n")
            f.write(
                "help:\n\t{0}\n".format(
                    """@grep -E '^[A-Za-z0-9_.-]+:.*?## .*$$' $(MAKEFILE_LIST) | sort | awk 'BEGIN {FS = ":.*?## "}; {printf "\033[36m%-30s\033[0m %s\\n", $$1, $$2}'\n"""
                )
            )
    else:
        print("Error: Makefile already exists")


@main.command()
@click.argument("name")
@click.argument("command")
@click.argument("description")
def add(name, command, description):
    makefile_exists = os.path.isfile("./Makefile")
    if not makefile_exists:
        print("Error: Makefile not found, you can create a new one using: pymake init")
    elif f"{name}:  ## " in open("./Makefile").read():
        print(f"Error: Makefile already has a command with name '{name}'")
    else:
        with open("./Makefile", "a+") as f:
            f.write(f"{name}:  ## {description}\n\t{command}\n\n")


if __name__ == "__main__":
    main()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pymakefile']

package_data = \
{'': ['*']}

install_requires = \
['click>=8.0.1,<9.0.0']

entry_points = \
{'console_scripts': ['pymake = pymakefile.pymakefile:main']}

setup_kwargs = {
    'name': 'pymakefile',
    'version': '0.1.1',
    'description': 'Manage your Makefiles from python',
    'long_description': "# pymakefile\nManage your Makefiles from python\n\n## Install\n\n## Usage\n\n### Starting a new Makefile\n`pymake init`\n\n### Add a new command to the Makefile\n`pymake add '{command_name}' '{command}' '{description}'`  \nExample:  \n`pymake add runlocal 'python manage.py runserver' 'Starts the development server'`\n\n## Development\n### Install dependencies\n`poetry install`\n### Activate virtualenv\n`poetry shell`\n### Running the commands from source\n- `python pymakefile.py init`\n- `python pymakefile.py add '{command_name}' '{command}' '{description}'`\n\n### Applying lint rules\n`black .`\n",
    'author': 'William',
    'author_email': 'macwilliamdlc@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/willbackslash/pymakefile',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
